@@ -3,7 +3,7 @@ from __future__ import annotations
 from dataclasses import dataclass
 from typing import TYPE_CHECKING, cast
 
-from ...util import get_client
+from ...util import get_client, time_cache
 
 if TYPE_CHECKING:  # pragma: no cover
     from typing import Optional
@@ -29,6 +29,7 @@ class ManifoldMarketMixin:
             slug = cast(str, self.url).split("/")[-1]
         self.id_ = get_client().get_market_by_slug(slug).id
 
+    @time_cache()
     def api_market(self, client: Optional[ManifoldClient] = None) -> APIMarket:
         if client is None:
             client = get_client()
