@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 from dataclasses import dataclass
 from itertools import chain
 from os import environ
@@ -5,7 +7,7 @@ from random import randrange
 from secrets import token_hex
 from typing import Any, List, cast
 
-from pytest import raises
+from pytest import mark, raises
 
 from .. import Rule
 from ..util import explain_abstract, require_env
@@ -35,6 +37,7 @@ def test_require_env() -> None:
                 environ[key] = orig
 
 
+@mark.network
 def test_explain_abstract() -> None:
     """Make sure that explain_abstract() calls to each of its fed Rules."""
     @dataclass
@@ -47,7 +50,7 @@ def test_explain_abstract() -> None:
 
     l1 = [MockObject() for _ in range(randrange(20))]
     l2 = [MockObject() for _ in range(randrange(20))]
-    val = explain_abstract(cast(List[Rule], l1), cast(List[Rule], l2))
+    val = explain_abstract(cast(List[Rule[Any]], l1), cast(List[Rule[Any]], l2))
     assert isinstance(val, str)
     for obj in chain(l1, l2):
         assert obj.called
